@@ -62,8 +62,11 @@ func (g *Gatherer) Gather(ctx context.Context, recorder record.Interface) error
 		GatherNetNamespace(g),
 		GatherServiceAccounts(g),
 		GatherSAPConfig(g),
+		GatherSAPVsystemIptablesLogs(g),
 		GatherSAPPods(g),
+		GatherSAPDatahubs(g),
 		GatherOpenshiftSDNControllerLogs(g),
+		GatherOLMOperators(g),
 	)
 }
 
